==> blancoNLpackGenerator-0.0.88a-src.zip: src/blanco/xliff/util/task/BlancoXliffUtilExtractNeedsTranslationTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoXliffUtilExtractNeedsTranslation]̃NX
 */
package blanco.xliff.util.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.xliff.util.task.valueobject.BlancoXliffUtilExtractNeedsTranslationProcessInput;

/**
 * Apache Ant^XN [BlancoXliffUtilExtractNeedsTranslation]̃NXB
 *
 * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂B{I target̂T܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.xliff.util.task]BlancoXliffUtilExtractNeedsTranslationBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoxliffutilextractneedstranslation&quot; classname=&quot;blanco.xliff.util.task.BlancoXliffUtilExtractNeedsTranslationTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoXliffUtilExtractNeedsTranslationTask extends Task {
    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂B{I target̂T܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected BlancoXliffUtilExtractNeedsTranslationProcessInput fInput = new BlancoXliffUtilExtractNeedsTranslationProcessInput();

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂B{I target̂T܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldTargetfileProcessed = false;

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂B{I target̂T܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldXliffdirProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C<br>
     *
     * @param arg Zbgl
     */
    public void setTargetfile(final String arg) {
        fInput.setTargetfile(arg);
        fIsFieldTargetfileProcessed = true;
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetfile() {
        return fInput.getTargetfile();
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C܂܂fBNgB<br>
     *
     * @param arg Zbgl
     */
    public void setXliffdir(final String arg) {
        fInput.setXliffdir(arg);
        fIsFieldXliffdirProcessed = true;
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C܂܂fBNgB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getXliffdir() {
        return fInput.getXliffdir();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoXliffUtilExtractNeedsTranslationTask begin.");

        // ڔԍ[1]AAgr[g[targetfile]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetfileProcessed == false) {
            throw new BuildException("K{Agr[g[targetfile]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[xliffdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldXliffdirProcessed == false) {
            throw new BuildException("K{Agr[g[xliffdir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- targetfile:[" + getTargetfile() + "]");
            System.out.println("- xliffdir:[" + getXliffdir() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoXliffUtilExtractNeedsTranslationProcessC^tF[X blanco.xliff.util.taskpbP[W BlancoXliffUtilExtractNeedsTranslationProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoXliffUtilExtractNeedsTranslationProcess proc = new BlancoXliffUtilExtractNeedsTranslationProcessImpl();
            if (proc.execute(fInput) != BlancoXliffUtilExtractNeedsTranslationBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoNLpackGenerator-0.0.92-src.zip: src/blanco/xliff/util/task/BlancoXliffUtilExtractNeedsTranslationTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoXliffUtilExtractNeedsTranslation]̃NX
 */
package blanco.xliff.util.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.xliff.util.task.valueobject.BlancoXliffUtilExtractNeedsTranslationProcessInput;

/**
 * Apache Ant^XN [BlancoXliffUtilExtractNeedsTranslation]̃NXB
 *
 * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.xliff.util.task]BlancoXliffUtilExtractNeedsTranslationBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoxliffutilextractneedstranslation&quot; classname=&quot;blanco.xliff.util.task.BlancoXliffUtilExtractNeedsTranslationTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoXliffUtilExtractNeedsTranslationTask extends Task {
    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected BlancoXliffUtilExtractNeedsTranslationProcessInput fInput = new BlancoXliffUtilExtractNeedsTranslationProcessInput();

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldTargetfileProcessed = false;

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldXliffdirProcessed = false;

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldGetstateneedstranslationProcessed = false;

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldGetstatenewProcessed = false;

    /**
     * [XLIFFΉc[] |󂪕Kv trans-unit 𒊏o܂Btranslate=&quot;no&quot;  trans-unit ̓XLbv܂B
     */
    protected boolean fIsFieldGettargetnotexistProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C<br>
     *
     * @param arg Zbgl
     */
    public void setTargetfile(final String arg) {
        fInput.setTargetfile(arg);
        fIsFieldTargetfileProcessed = true;
    }

    /**
     * Ant^XN[targetfile]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * o͑Ώۂ XLIFF (*.xlf) t@C<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetfile() {
        return fInput.getTargetfile();
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C܂܂fBNgB<br>
     *
     * @param arg Zbgl
     */
    public void setXliffdir(final String arg) {
        fInput.setXliffdir(arg);
        fIsFieldXliffdirProcessed = true;
    }

    /**
     * Ant^XN[xliffdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * ͑Ώۂ XLIFF (*.xlf) t@C܂܂fBNgB<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getXliffdir() {
        return fInput.getXliffdir();
    }

    /**
     * Ant^XN[getstateneedstranslation]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * state  needs-translation  trans-unit 擾邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setGetstateneedstranslation(final boolean arg) {
        fInput.setGetstateneedstranslation(arg);
        fIsFieldGetstateneedstranslationProcessed = true;
    }

    /**
     * Ant^XN[getstateneedstranslation]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * state  needs-translation  trans-unit 擾邩ǂB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getGetstateneedstranslation() {
        return fInput.getGetstateneedstranslation();
    }

    /**
     * Ant^XN[getstatenew]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * state  new  trans-unit 擾邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setGetstatenew(final boolean arg) {
        fInput.setGetstatenew(arg);
        fIsFieldGetstatenewProcessed = true;
    }

    /**
     * Ant^XN[getstatenew]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * state  new  trans-unit 擾邩ǂB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getGetstatenew() {
        return fInput.getGetstatenew();
    }

    /**
     * Ant^XN[gettargetnotexist]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     *  target ݂Ȃ trans-unit 擾邩ǂB<br>
     *
     * @param arg Zbgl
     */
    public void setGettargetnotexist(final boolean arg) {
        fInput.setGettargetnotexist(arg);
        fIsFieldGettargetnotexistProcessed = true;
    }

    /**
     * Ant^XN[gettargetnotexist]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     *  target ݂Ȃ trans-unit 擾邩ǂB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getGettargetnotexist() {
        return fInput.getGettargetnotexist();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoXliffUtilExtractNeedsTranslationTask begin.");

        // ڔԍ[1]AAgr[g[targetfile]͕K{͂łB̓`FbNs܂B
        if (fIsFieldTargetfileProcessed == false) {
            throw new BuildException("K{Agr[g[targetfile]ݒ肳Ă܂B𒆒f܂B");
        }
        // ڔԍ[2]AAgr[g[xliffdir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldXliffdirProcessed == false) {
            throw new BuildException("K{Agr[g[xliffdir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- targetfile:[" + getTargetfile() + "]");
            System.out.println("- xliffdir:[" + getXliffdir() + "]");
            System.out.println("- getstateneedstranslation:[" + getGetstateneedstranslation() + "]");
            System.out.println("- getstatenew:[" + getGetstatenew() + "]");
            System.out.println("- gettargetnotexist:[" + getGettargetnotexist() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoXliffUtilExtractNeedsTranslationProcessC^tF[X blanco.xliff.util.taskpbP[W BlancoXliffUtilExtractNeedsTranslationProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoXliffUtilExtractNeedsTranslationProcess proc = new BlancoXliffUtilExtractNeedsTranslationProcessImpl();
            if (proc.execute(fInput) != BlancoXliffUtilExtractNeedsTranslationBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
